trouble-host

Crates

0.6.0

Versions

default

Flavors

CharacteristicBuilder

Struct CharacteristicBuilder 

pub struct CharacteristicBuilder<'r, 'd, T: AsGatt + ?Sized, M: RawMutex, const MAX: usize> { /* private fields */ }
Builder for characteristics.

Implementations

Source

impl<'r, 'd, T: AsGatt + ?Sized, M: RawMutex, const MAX: usize> CharacteristicBuilder<'r, 'd, T, M, MAX>

pub fn add_descriptor<DT: AsGatt, U: Into<Uuid>>( &mut self, uuid: U, permissions: AttPermissions, value: DT, store: &'d mut [u8], ) -> Descriptor<DT>

Add a characteristic descriptor for this characteristic.

pub fn add_descriptor_small<DT: AsGatt, U: Into<Uuid>>( &mut self, uuid: U, permissions: AttPermissions, value: DT, ) -> Descriptor<DT>

Add a characteristic to this service using inline storage. The descriptor value must be 8 bytes or less.

pub fn add_descriptor_ro<DT: AsGatt + ?Sized, U: Into<Uuid>>( &mut self, uuid: U, read_permission: PermissionLevel, data: &'d DT, ) -> Descriptor<DT>

Add a read only characteristic descriptor for this characteristic.

pub fn read_permission(self, read: PermissionLevel) -> Self

Set the read permission for this characteristic

pub fn write_permission(self, write: PermissionLevel) -> Self

Set the write permission for this characteristic

pub fn cccd_permission(self, write: PermissionLevel) -> Self

Set the write permission for the Client Characteristic Configuration Descriptor for this characteristic

Panics if this characteristic does not have a Client Characteristic Configuration Descriptor.

pub fn to_raw(self) -> CharacteristicBuilder<'r, 'd, [u8], M, MAX>

Convert this characteristic’s type to raw bytes

pub fn build(self) -> Characteristic<T>

Return the built characteristic.